==> gamgi_0.14.5.orig.tar.gz: gamgi0.14.5/src/gtk/group/gamgi_gtk_group_modify.h <==
/*************************************************
 *
 * $GAMGI/src/gtk/group/gamgi_gtk_group_modify.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static gamgi_bool static_scan (gamgi_group *group, gamgi_dlist *start,
double *position, gamgi_atom **central);

static gamgi_bool static_find (gamgi_group *group, gamgi_atom **atom);

static void static_remove (gamgi_group *group);

static gamgi_enum static_class (gamgi_window *window);

static void static_number (GtkWidget *widget, void *data);

static void static_start_polytope (gamgi_window *window);

static void static_start_container (gamgi_window *window);

static void static_start_position (gamgi_window *window);

static void static_autonomy (GtkWidget *widget, void *data);

static void static_type (GtkWidget *widget, void *data);

static void static_ok_polytope (gamgi_group *group, gamgi_window *window);

static void static_ok_container (gamgi_group *group, gamgi_window *window);

static void static_global (GtkWidget *widget, void *data);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_group_modify_press (gamgi_window *window_mouse,
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_group_modify (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Under development.

 *************
 * Rationale *
 *************/

==> gamgi_0.15.5.orig.tar.gz: gamgi0.15.5/src/gtk/group/gamgi_gtk_group_modify.h <==
/*************************************************
 *
 * $GAMGI/src/gtk/group/gamgi_gtk_group_modify.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static gamgi_bool static_scan (gamgi_group *group, gamgi_dlist *start,
double *position, gamgi_atom **central);

static gamgi_bool static_find (gamgi_group *group, gamgi_atom **atom);

static void static_remove (gamgi_group *group);

static gamgi_enum static_class (gamgi_window *window);

static void static_number (GtkWidget *widget, void *data);

static void static_start_polytope (gamgi_window *window);

static void static_start_container (gamgi_window *window);

static void static_start_position (gamgi_window *window);

static void static_autonomy (GtkWidget *widget, void *data);

static void static_type (GtkWidget *widget, void *data);

static void static_list (GtkWidget *widget, void *data);

static gamgi_bool static_grab (gamgi_window *window);

static gamgi_bool static_apply (gamgi_cell *cell, gamgi_window *window);

static void static_ok_global (gamgi_window *window);

static void static_ok_local (gamgi_window *window);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_group_modify_press (gamgi_window *window_mouse,
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_group_modify (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Under development.

 *************
 * Rationale *
 *************/
